@@ -1,5 +1,6 @@
 from s3fs import S3FileSystem
 from pandas import read_csv
+from pandas import DataFrame as PandasDF
 from pickle import dump as pickle_dump
 from pickle import load as pickle_load
 from psycopg2 import connect as psycopg2_connect
@@ -115,14 +116,14 @@ class S3:
 		"""
 
 		:type data: SparkDF
-		:param path:
-		:param index:
-		:param kwargs:
-		:return:
+		:type path: str
+		:type index: bool
+		:type encoding: str
+		:rtype:
 		"""
 		path = self._get_absolute_path(path)
-		bytes = data.to_csv(path_or_buf=None, quoting=QUOTE_NONNUMERIC, index=index, **kwargs).encode(encoding)
-		self.write(path=path, bytes=bytes)
+		_bytes = data.to_csv(path_or_buf=None, quoting=QUOTE_NONNUMERIC, index=index, **kwargs).encode(encoding)
+		return self.write_bytes(path=path, bytes=_bytes)
 
 	def read_bytes(self, path):
 		with self.file_system.open(path=self._root+path, mode='rb') as f:
@@ -138,7 +139,7 @@ class S3:
 	def write_pickle(self, obj, path, mode='overwite'):
 		"""
 
-		:type obj: SparkDF
+		:type obj: PandasDF or object
 		:type path: str
 		:type mode: str
 		:rtype: bool
@@ -153,7 +154,7 @@ class S3:
 		with self.file_system.open(path=path, mode='wb') as f:
 			try:
 				return obj.to_pickle(f)
-			except:
+			except Exception as e:
 				if self.exists(path=path):
 					self.delete(path=path)
 				try:
